@@ -765,6 +765,7 @@ main(int argc, char **argv)
 		    /* it is an embedded stylesheet */
 		    xsltProcess(style, cur, argv[i]);
 		    xsltFreeStylesheet(cur);
+		    cur = NULL;
 		    goto done;
 		}
 		cur = xsltParseStylesheetDoc(style);
@@ -773,10 +774,6 @@ main(int argc, char **argv)
 			errorno = 5;
 			goto done;
 		    }
-		    if (cur->indent == 1)
-			xmlIndentTreeOutput = 1;
-		    else
-			xmlIndentTreeOutput = 0;
 		    i++;
 		} else {
 		    xmlFreeDoc(style);
